==> gnome-desktop-2.2.1.tar.bz2: gnome-desktop-2.2.1/gnome-about/contributors.h <==
#include <libgnome/libgnome.h>

/* If your name uses some letters not in 7bit ascii, or a non-lati script;
 * put your name in ascii enclosed with N_( ) and put a comment before your
 * line giving some info on how it should be written for languages that
 * support the proper letters/script for your name. So for example someone
 * with a name normally written in cyrillic can have it displayed in cyrillic
 * for those languages supporting it */ 


/* Please keep this in alphabetical order */
static gchar *contributors[] = {
	"Jerome Abela",
	"Lauri Alanko",
	"Seth Alves",
	"Shawn T. Amundson",
	"Erik Andersen",
	"Marius Andreiana",
	"Jon Anhold",
	N_("Timur I. Bakeyev"),
	/* if your encoding allows it, use aacute (U00E1) 
	 * for the 'a' of 'Ban' */
	N_("Szabolcs 'Shooby' Ban"),
	"Martin Baulig",
	"Tom Bech",
	"Andreas Beck",
	"Carlos Amador Bedolla",
	"Martijn van Beers",
	"Frank Belew",
	"Calum Benson",
	"Jacob Berkman",
	"Eckehard Berns",
	"Robert Bihlmeyer",
	"Jonathan Blandford",
	"Christopher Blizzard",
	N_("Jerome Bolliet"),
	"Andreas Bolsch",
	"Dave Bordoley",
	"Dario Bressanini",
	"Emmanuel Briot",
	"Stephen Browne",
	"Marcus Brubaker",
	"Christian Bucher",
	"Ross Burton",
	"Brian Cameron",
	"Dave Camp",
	"Didier Carlier",
	"Anders Carlsson",
	"Chema Celorio",
	"Damon Chaplin",
	"Kevin Charter",
	/* if your encoding allows it, use eacute (U00E9) for the first 
	 * and the last 'e' in 'Chenede' */
	N_("Erwann Chenede"),
	/* CJK people please use (U5F35) (U570B) (U51A0) to replace
	 * this name */
	N_("Abel Cheung"),
	"Kenneth Rohde Christiansen",
	"Chad Clark",
	"Matthias Clasen",
	"Andrew Clausen",
	"Jeremy Collins",
	"Rusty Conover",
	"Pat Costello",
	"Alan Cox",
	"Dennis Cranston",
	"Mark Crichton",
	/* if you encoding allows it, use eacute (U00E9) for the two
	 * 'e' of 'Frederic' */
	N_("Frederic Crozat"),
	"Andreas Czechanowski",
	"Johan Dahlin",
	"Dan Damian",
	"Phil Dawes",
	"Fatih Demir",
	/* if your encoding allows it, use eacute (U00E9) for the two
	 * 'e' of 'Frederic' */
	N_("Frederic Devernay"),
	"Dietmar Maurer",
	"Feico W. Dillema",
	"Radek Doulik",
	"Tom Dyas",
	"Karl Eichwalder",
	"John Ellis",
	"Arturo Espinosa",
	"Gus Estrella",
	"David Etherton",
	"Larry Ewing",
	"Marc Ewing",
	/* if your encoding allows it, use odoubleacute (U0151) for the 'o'
	 * of 'Gergo' and use Eacute (U00C9) for the 'E' of 'Erdi' */
	N_("Gergo Erdi"),
	"Peter Fales",
	"Joaquim Fellmann",
	"Jens Finke",
	"Dave Finton",
	"Milon Firikis",
	"John Fleck",
	N_("Raul Perusquia Flores"),
	"Lawrence Foard",
	"Glynn Foster",
	"Ben FrantzDale",
	"Jeff Freedman",
	"David Abilleira Freijeiro",
	"Nat Friedman",
	"Jochen Friedrich",
	"Adam Fritzler",
	"Michael Fulbright",
	"Christopher R. Gabriel",
	"Mark Galassi",
	"Tony Gale",
	"Jeff Garzik",
	N_("The Mysterious GEGL"),
	"Tim Gerla",
	N_("Bjoern Giesler"),
	"Dave Glowacki",
	"Scott Goehring",
	"Randy Gordon",
	"Kenny Graunke",
	"Jamin Philip Gray",
	N_("Dov Grobgeld"),
	"Bertrand Guiheneuf",
	"Alan Aspuru Guzik",
	"Telsa Gwynne",
	"Fredrik Hallenberg",
        "Mikael Hallendal",
	"Lars Hamann",
	"Michael Hanni",
	"Raja R Harinath",
	"Heath Harrelson",
	"Peter Hawkins",
	"Scott Heavner",
	"James Henstridge",
        "Fernando Herrera",
	"Richard Hestilow",
	"Iain Holmes",
	"David Huggins-Daines",
	"Richard Hult",
	"Andreas Hyden",
	"Miguel de Icaza",
	"Tim Janik",
	"Stefan Jeske",
	/* Wang is the surname. CJK people, please use (U738B) (U5251)
	 * to replace this name. */
	N_("Wang Jian"),
	"Michael K. Johnson",
	"Andy Kahn",
	"Sami Kananoja",
	"Michael Kellen",
	"Stephen Kiernan",
	"Spencer Kimball",
	"Alexander Kirillov",
	"Peter Kirchgessner",
	N_("Helmut Koeberle"),
	"Alfredo Kojima",
	"Andrew Kuchling",
	"Stephan Kulow",
	"Martynas Kunigelis",
	"Tuomas Kuosmanen",
	"Olof Kylander",
	"Mathieu Lacage", 
	"Francis J. Lacoste",
	"Chris Lahey",
	"Scott Laird",
	"Birger Langkjer",
	"Alexander Larsson",
	"Guillaume Laurent",
	"Ole Laursen",
	"Michael Lausch",
	"Will LaShell",
	"Jens Lautenbacher",
	"Evan Lawrence",
	"Garrett LeSage",
	"Jason Leach",
	"George Lebl",
	"Gregory Leblanc",
	"Elliot Lee",
	"Marc Lehmann",
	"Raph Levien",
	"Matt Loper",
	"Nick Lopez",
	"Dirk Lutjens",
	"Josh MacDonald",
	"Paolo Maggi",
	"Sam Magnuson",
	"Ian Main",
        "Jordi Mallach",
	"Mandrake",
	"Daniel Manrique",
	"Kjartan Maraas",
	N_("Matthew Marjanovic"),
	"Heath Martin",
	"Oliver Maruhn",
	"Dave Mason",
	"James Mastros",
	"Peter Mattis",
	"Gordon Matzigkeit",
	"Justin Maurer",
	"Gregory McLean",
	"Mark McLoughlin",
	"Michael Meeks",
	"Federico Mena-Quintero",
	"Christophe Merlet",
	"Christian Meyer",
	"Cesar Miquel",
	"Julian Missig",
	"Eric B. Mitchell",
	"Jaka Mocnik",
	"Paolo Molaro",
	"David Mosberger",
	"Rodrigo Moya",
	"Dan Mueth",
	"Thomas Muldowney",
	/* If your encodings allows it, use ntilde (U00F1) for the 'n'
	 * of 'Muniz' */
	N_("Alexandre Muniz"),
	/* Name in Hangeul is: Ub0a8 Uc131 Ud604 */
	N_("Sung-Hyun Nam"),
	"Deepa Natarajan",
	"Karl Nelson",
	"Asger Alstrup Nielsen",
	"Seth Nickell",
	"Eric Nielson",
	"Bastien Nocera",
	/* If your encodings allows it, use adiaeresis (U00E4) for the 'ae'
	 * of 'Norbaeck' */
	N_("Martin Norbaeck"),
	"Eskil Olsen",
	"Jimmy Olsen",
	"David Orme",
	"Karl Anders Oygard",
	/* If your encodings allows it, use Odiaeresis (U00D6) for the 'Oe'
	 * of 'Oegren' */
	N_("Tomas Oegren"),
	"Jay Painter",
	"Cameron Parish",
	"Conrad Parker",
	"Stuart Parmenter",
	"Nils Pedersen",
	"Havoc Pennington",
	"Ettore Perazzoli",
	/* If your encoding allows it, use oacute (U00F3) for the 'o'
	 * of 'Perello' and use iacute (U00ED) for the 'i' of 'Marin' */
	N_("Carlos Perello Marin"),
	"Ian Peters",
	"Martin Kasper Petersen",
	"Christof Petig",
	"Joe Pfeiffer",
	"Ben Pierce",
	"Chris Pinkham",
	/* If your encoding allows it, use aacute (U00E1) for the 'a'
	 * of 'German' and use ntilde (U00F1) for the 'n' of 'Caamano' */
	N_("German Poo-Caamano"),
	"Dick Porter",
	"Tero Pulkkinen",
	"The Rasterman",
	"Oliver Rauch",
	"Christian Rose",
	"Cody Russell",
	"Reklaw",
	"Jens Christian Restemeier",
	"Patrick Reynolds",
	"Robert Richardson",
	"Kristian Rietveld",
	"Alex Roberts",
	"Michel Roelofs",
	"Ueli Rutishauser",
	"Lars Rydlinge",
	"Peter Ryland",
	"Bibek Sahu",
	"Arvind Samptur",
	"S\xc3\xb8ren Sandmann",
	"Pablo Saratxaga",
	/* Name in Japanese is: U7b39 U5c71 U548c U5b8f */
	N_("Kazuhiro Sasayama"),
	"Carsten Schaar",
	"Christian Schaller",
	"Wayne Schuller",
	"Franck Schneider",
	"Ingo Schneider",
	"Bernd Schroeder",
	"John Schulien",
	/* If your encodings allows it, use ntilde (U00F1) for the 'n'
	 * of 'Inigo' */
	N_("Inigo Serna"),
	"Shaleh",
	"Joe Shaw",
	"Alejandro Aguilar Sierra",
	N_("Miroslav Silovic"),
	"Manish Singh",
	"Timo Sirainen",
	"David F. Skoll",
	"Nuke Skyjumper",
	"Josh Sled",
	"John Slee",
	"Garrett Smith",
	"Suzanna Smith",
	"Andrew Sobala",
	/* not really a person name :) translate its meaning */
	N_("The Squeaky Rubber Gnome"),
	"Maciej Stachowiak",
	"Stalyn",
	"Jeffrey Stedfast",
	"Jakub Steiner",
	"Ben Stern",
	"Micah Stetson",
	"Nathan Carl Summers",
	N_("Istvan Szekeres"),
	"HideToshi Tajima",
	"Tristan Tarrant",
	"Anthony Taylor",
	"Owen Taylor",
	"Peter Teichman",
	"Arturo Tena",
	"Kimball Thurston",
	"Chris Toshok",
	"Christoph Toshok",
	"Tom Tromey",
	"Jon Trowbridge",
	"Vincent Untz",
	N_("Manish Vachharajani"),
	N_("Neil Vachharajani"),
	"Thomas Vander Stichele",
	"Daniel Veillard",
	"Vendu",
	"Andrew Veliath",
	"Luis Villa",
	"Marius Vollmer",
	"Shawn Wagner",
	N_("Wanda the GNOME Fish"),
	"Matthias Warkus",
	"Jeff Waugh",
	"Bruno Widmann",
	"Robert Wilhelm",
	"Sebastian Wilhelmi",
	"James Willcox",
	"David Winkler",
	"Jeremy Wise",
	"Roger Wolff",
	"Frank Worsley",
	"James Youngman",
	"Orest Zborowski",
	"Sascha Ziemann",
	"Michael Zucchi",
	"Jason van Zyl",
	"",
	""
};

==> gnome-desktop-2.3.2.tar.bz2: gnome-desktop-2.3.2/gnome-about/contributors.h <==
#include <libgnome/libgnome.h>

/* If your name uses some letters not in 7bit ascii, or a non-lati script;
 * put your name in ascii enclosed with N_( ) and put a comment before your
 * line giving some info on how it should be written for languages that
 * support the proper letters/script for your name. So for example someone
 * with a name normally written in cyrillic can have it displayed in cyrillic
 * for those languages supporting it */ 


/* Please keep this in alphabetical order */
static gchar *contributors[] = {
	"J\xc3\xa9r\xc3\xb4me Abela",
	"Lauri Alanko",
	"Seth Alves",
	"Shawn T. Amundson",
	"Erik Andersen",
	"Marius Andreiana",
	"Jon Anhold",
	"Timur I. Bakeyev",
	"Szabolcs 'Shooby' B\xc3\xa1n",
	"Martin Baulig",
	"Tom Bech",
	"Andreas Beck",
	"Carlos Amador Bedolla",
	"Martijn van Beers",
	"Frank Belew",
	"Calum Benson",
	"Jacob Berkman",
	"Eckehard Berns",
	"Robert Bihlmeyer",
	"Jonathan Blandford",
	"Christopher Blizzard",
	"J\xc3\xa9r\xc3\xb4me Bolliet",
	"Andreas Bolsch",
	"Dave Bordoley",
	"Dario Bressanini",
	"Emmanuel Briot",
	"Stephen Browne",
	"Marcus Brubaker",
	"Christian Bucher",
	"Ross Burton",
	"Brian Cameron",
	"Dave Camp",
	"Didier Carlier",
	"Anders Carlsson",
	"Chema Celorio",
	"Damon Chaplin",
	"Kevin Charter",
	"Erwann Ch\xc3\xa9ned\xc3\xa9",
	 /* Abel Cheung: */
	"\xe5\xbc\xb5 \xe5\x9c\x8b \xe5\x86\xa0",
	"Kenneth Rohde Christiansen",
	"Chad Clark",
	"Matthias Clasen",
	"Andrew Clausen",
	"Jeremy Collins",
	"Rusty Conover",
	"Pat Costello",
	"Alan Cox",
	"Dennis Cranston",
	"Mark Crichton",
	"Fr\xc3\xa9" "d\xc3\xa9ric Crozat",
	"Andreas Czechanowski",
	"Johan Dahlin",
	"Dan Damian",
	"Phil Dawes",
	"Fatih Demir",
	"Fr\xc3\xa9" "d\xc3\xa9ric Devernay",
	"Feico W. Dillema",
	"Radek Doulik",
	"Alex Duggan",
	"Tom Dyas",
	"Karl Eichwalder",
	"John Ellis",
	"Arturo Espinosa",
	"Gus Estrella",
	"David Etherton",
	"Larry Ewing",
	"Marc Ewing",
	"Gerg\xc5\x91 \xc3\x89rdi",
	"Peter Fales",
	"Joaquim Fellmann",
	"Jens Finke",
	"Dave Finton",
	"Milon Firikis",
	"John Fleck",
	"Ra\xc3\xbal Perusquia Flores",
	"Lawrence Foard",
	"Glynn Foster",
	"Ben FrantzDale",
	"Jeff Freedman",
	"David Abilleira Freijeiro",
	"Nat Friedman",
	"Jochen Friedrich",
	"Adam Fritzler",
	"Michael Fulbright",
	"Christopher R. Gabriel",
	"Mark Galassi",
	"Tony Gale",
	"Jeff Garzik",
	N_("The Mysterious GEGL"),
	"Tim Gerla",
	"Bj\xc3\xb6rn Giesler",
	"Dave Glowacki",
	"Scott Goehring",
	"Randy Gordon",
	"Kenny Graunke",
	"Jamin Philip Gray",
	"Dov Grobgeld",
	"Bertrand Guiheneuf",
	"Alan Aspuru Guzik",
	"Telsa Gwynne",
	"Fredrik Hallenberg",
        "Mikael Hallendal",
	"Lars Hamann",
	"Michael Hanni",
	"Raja R Harinath",
	"Heath Harrelson",
	"Peter Hawkins",
	"Scott Heavner",
	"James Henstridge",
        "Fernando Herrera",
	"Richard Hestilow",
	"Iain Holmes",
	"David Huggins-Daines",
	"Richard Hult",
	"Andreas Hyden",
	"Miguel de Icaza",
	"Tim Janik",
	"Stefan Jeske",
	/* Wang Jian: */
	"\xe7\x8e\x8b \xe5\x89\x91",
	"Michael K. Johnson",
	"Andy Kahn",
	"Sami Kananoja",
	"Michael Kellen",
	"Stephen Kiernan",
	"Spencer Kimball",
	"Alexander Kirillov",
	"Peter Kirchgessner",
	"Helmut K\xc3\xb6" "berle",
	"Alfredo Kojima",
	"Andrew Kuchling",
	"Stephan Kulow",
	"Martynas Kunigelis",
	"Tuomas Kuosmanen",
	"Olof Kylander",
	"Mathieu Lacage", 
	"Francis J. Lacoste",
	"Chris Lahey",
	"Scott Laird",
	"Birger Langkjer",
	"Alexander Larsson",
	"Guillaume Laurent",
	"Ole Laursen",
	"Michael Lausch",
	"Will LaShell",
	"Jens Lautenbacher",
	"Evan Lawrence",
	"Garrett LeSage",
	"Jason Leach",
	"George Lebl",
	"Gregory Leblanc",
	"Elliot Lee",
	"Marc Lehmann",
	"Raph Levien",
	"Matt Loper",
	"Nick Lopez",
	"Dirk Lutjens",
	"Josh MacDonald",
	"Paolo Maggi",
	"Sam Magnuson",
	"Ian Main",
        "Jordi Mallach",
	"Mandrake",
	"Daniel Manrique",
	"Kjartan Maraas",
	"Matthew Marjanovic",
	"Heath Martin",
	"Oliver Maruhn",
	"Dave Mason",
	"James Mastros",
	"Peter Mattis",
	"Gordon Matzigkeit",
	"Dietmar Maurer",
	"Justin Maurer",
	"Gregory McLean",
	"Mark McLoughlin",
	"Michael Meeks",
	"Federico Mena-Quintero",
	"Christophe Merlet",
	"Christian Meyer",
	"Cesar Miquel",
	"Julian Missig",
	"Eric B. Mitchell",
	"Jaka Mocnik",
	"Paolo Molaro",
	"David Mosberger",
	"Rodrigo Moya",
	"Dan Mueth",
	"Thomas Muldowney",
	"Alexandre Mu\xc3\xb1iz",
	/* Sung-Hyun Nam: */
	"\xeb\x82\xa8 \xec\x84\xb1 \xed\x98\x84",
	"Deepa Natarajan",
	"Karl Nelson",
	"Elijah Newren",
	"Christian Neumair",
	"Asger Alstrup Nielsen",
	"Seth Nickell",
	"Eric Nielson",
	"Bastien Nocera",
	"Martin Norb\xc3\xa4" "ck",
	"Eskil Olsen",
	"Jimmy Olsen",
	"David Orme",
	"Karl Anders Oygard",
	"Tomas \xc3\x96gren",
	"Jay Painter",
	"Cameron Parish",
	"Conrad Parker",
	"Stuart Parmenter",
	"Nils Pedersen",
	"Havoc Pennington",
	"Ettore Perazzoli",
	"Carlos Perell\xc3\xb3 Mar\xc3\xadn",
	"Ian Peters",
	"Martin Kasper Petersen",
	"Christof Petig",
	"Joe Pfeiffer",
	"Ben Pierce",
	"Chris Pinkham",
	"Germ\xc3\xa1n Poo-Caama\xc3\xb1o",
	"Dick Porter",
	"Tero Pulkkinen",
	"The Rasterman",
	"Oliver Rauch",
	"Christian Rose",
	"Cody Russell",
	"Reklaw",
	"Jens Christian Restemeier",
	"Patrick Reynolds",
	"Robert Richardson",
	"Kristian Rietveld",
	"Alex Roberts",
	"Michel Roelofs",
	"Ueli Rutishauser",
	"Lars Rydlinge",
	"Peter Ryland",
	"Bibek Sahu",
	"Arvind Samptur",
	"S\xc3\xb8ren Sandmann",
	"Pablo Saratxaga",
	/* Kazuhiro Sasayama: */
	"\xe7\xac\xb9 \xe5\xb1\xb1 \xe5\x92\x82 \xe5\xae\x8f",
	"Carsten Schaar",
	"Christian Schaller",
	"Wayne Schuller",
	"Franck Schneider",
	"Ingo Schneider",
	"Bernd Schroeder",
	"John Schulien",
	"I\xc3\xb1igo Serna",
	"Shaleh",
	"Joe Shaw",
	"Alejandro Aguilar Sierra",
	"Miroslav Silovic",
	"Manish Singh",
	"Timo Sirainen",
	"David F. Skoll",
	"Nuke Skyjumper",
	"Josh Sled",
	"John Slee",
	"Garrett Smith",
	"Suzanna Smith",
	"Andrew Sobala",
	N_("The Squeaky Rubber Gnome"),
	"Maciej Stachowiak",
	"Stalyn",
	"Jeffrey Stedfast",
	"Jakub Steiner",
	"Ben Stern",
	"Micah Stetson",
	"Nathan Carl Summers",
	"Istvan Szekeres",
	"HideToshi Tajima",
	"Tristan Tarrant",
	"Anthony Taylor",
	"Owen Taylor",
	"Peter Teichman",
	"Arturo Tena",
	"Kimball Thurston",
	"Chris Toshok",
	"Christoph Toshok",
	"Tom Tromey",
	"Jon Trowbridge",
	"Vincent Untz",
	"Manish Vachharajani",
	"Neil Vachharajani",
	"Thomas Vander Stichele",
	"Daniel Veillard",
	"Vendu",
	"Andrew Veliath",
	"Luis Villa",
	"Marius Vollmer",
	"Shawn Wagner",
	N_("Wanda The GNOME Fish"),
	"Matthias Warkus",
	"Jeff Waugh",
	"Bruno Widmann",
	"Robert Wilhelm",
	"Sebastian Wilhelmi",
	"James Willcox",
	"David Winkler",
	"Jeremy Wise",
	"Roger Wolff",
	"Frank Worsley",
	"James Youngman",
	"Orest Zborowski",
	"Sascha Ziemann",
	"Michael Zucchi",
	"Jason van Zyl",
	"",
	""
};
